# buildforkernels macro hint: when you build a new version or a new release
# that contains bugfixes or other improvements then you must disable the
# "buildforkernels newest" macro for just that build; immediately after
# queuing that build enable the macro again for subsequent builds; that way
# a new akmod package will only get build when a new one is actually needed

# %define buildforkernels newest
%define buildforkernels current

%define tname open-vm-tools
%define VER		9.2.2
%define buildver	893683
%define ovtmodules vmblock vmci vmhgfs vmsync vmxnet vsock

Name:      open-vm-tools-kmod
Version:   %{VER}.%{buildver}
Release:   1%{?dist}.13
Summary:   VMware Tools Kernel Modules
Group:     System Environment/Kernel
License:   GPLv2-42
URL:       http://open-vm-tools.sourceforge.net/
Source0:   http://downloads.sourceforge.net/%{tname}/%{tname}-%{VER}-%{buildver}.tar.gz
Source11:  %{tname}-excludekernel-filterfile
Patch1:    %{name}-%{version}-patch-001
Patch2:    %{name}-%{version}-patch-002
BuildRoot: %{_tmppath}/%{name}-%{VER}-%{release}-root-%(%{__id_u} -n)

# VMWare only supports x86 architectures.
ExclusiveArch:  %{ix86} x86_64
# ExclusiveArch:  i686 x86_64

# get the needed BuildRequires (in parts depending on what we build for)
BuildRequires:  %{_bindir}/kmodtool
%{!?kernels:BuildRequires: buildsys-build-rpmfusion-kerneldevpkgs-%{?buildforkernels:%{buildforkernels}}%{!?buildforkernels:current}-%{_target_cpu} }
# kmodtool does its magic here
%{expand:%(kmodtool --target %{_target_cpu} --repo rpmfusion --kmodname %{name} --filterfile %{SOURCE11} %{?buildforkernels:--%{buildforkernels}} %{?kernels:--for-kernels "%{?kernels}"} 2>/dev/null) }

%description
Open-vm-tools are the open source implementation of VMware Tools. They
are a set of guest operating system virtualization components that
enhance performance and user experience of VMWare virtual
machines. This package contains the kernel modules of open-vm-tools.


%prep
# error out if there was something wrong with kmodtool
%{?kmodtool_check}
# print kmodtool output for debugging purposes:
kmodtool  --target %{_target_cpu}  --repo rpmfusion --kmodname %{name} --filterfile %{SOURCE11} %{?buildforkernels:--%{buildforkernels}} %{?kernels:--for-kernels "%{?kernels}"} 2>/dev/null

%setup -q -n open-vm-tools-%{VER}-%{buildver}
%patch1 -p1
%patch2 -p1
for kernel_version  in %{?kernel_versions} ; do
    mkdir -p _kmod_build_${kernel_version%%___*}/
    cp -ar modules _kmod_build_${kernel_version%%___*}/
    cp -ar lib _kmod_build_${kernel_version%%___*}/
done


%build
for kernel_version  in %{?kernel_versions} ; do
    for ovtmodule in %{ovtmodules}; do
        make -C ${PWD}/_kmod_build_${kernel_version%%___*}/modules/linux/${ovtmodule} VM_UNAME=${kernel_version%%___*} HEADER_DIR="${kernel_version##*___}/include" OVT_SOURCE_DIR=${PWD}/_kmod_build_${kernel_version%%___*} CC_OPTS=-DVMW_HAVE_EPOLL
    done
done


%install
rm -rf $RPM_BUILD_ROOT
for kernel_version  in %{?kernel_versions} ; do
    for ovtmodule in %{ovtmodules}; do
        install -D -m 755 _kmod_build_${kernel_version%%___*}/modules/linux/${ovtmodule}/${ovtmodule}.ko $RPM_BUILD_ROOT%{kmodinstdir_prefix}/${kernel_version%%___*}/%{kmodinstdir_postfix}/${ovtmodule}.ko
    done
done
# akmods:
%{?akmod_install}


%clean
rm -rf $RPM_BUILD_ROOT


%changelog
* Mon Feb 18 2013 Lawrence Rogers < lrr [AT] cert [DOT] org > - 9.2.2.893683-1.13
- Rebuild for kernel 3.7.8-202

* Sun Feb 10 2013 Lawrence Rogers < lrr [AT] cert [DOT] org > - 9.2.2.893683-1.12
- Rebuild for kernel 3.7.6-201

* Tue Feb 5 2013 Lawrence Rogers < lrr [AT] cert [DOT] org > - 9.2.2.893683-1.11
- Rebuild for kernel 3.7.5-201

* Thu Jan 31 2013 Lawrence Rogers < lrr [AT] cert [DOT] org > - 9.2.2.893683-1.10
- Rebuild for kernel 3.7.4-204

